import QtQuick 2.0
import QtQuick.LocalStorage 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.Popups 0.1
import Ubuntu.Components.Extras.Browser 0.1


MainView {
    objectName: "mainView"
    applicationName: "com.ubuntu.developer.ogra.book"
    automaticOrientation: false

    property var db: null

    function openDB() {
        if(db !== null) return;

        db = LocalStorage.openDatabaseSync("book-app", "0.1", "Simple bookreader app", 100000);

        try {
            db.transaction(function(tx){
                tx.executeSql('CREATE TABLE IF NOT EXISTS settings(key TEXT UNIQUE, value TEXT)');
                var table  = tx.executeSql("SELECT * FROM settings");
                // Seed the table with default values
                if (table.rows.length == 0) {
                    tx.executeSql('INSERT INTO settings VALUES(?, ?)', ["distro", "Ubuntu"]);
                    tx.executeSql('INSERT INTO settings VALUES(?, ?)', ["foo", "Bar"]);
                    console.log('Settings table added');
                };
            });
        } catch (err) {
            console.log("Error creating table in database: " + err);
        };
    }

    function saveSetting(key, value) {
        openDB();
        db.transaction( function(tx){
            tx.executeSql('INSERT OR REPLACE INTO settings VALUES(?, ?)', [key, value]);
        });
    }

    function getSetting(key) {
        openDB();
        var res = "";
        db.transaction(function(tx) {
            var rs = tx.executeSql('SELECT value FROM settings WHERE key=?;', [key]);
            res = rs.rows.item(0).value;
        });
        return res;
    }

    property int page: getSetting("page")

    Component {
         id: dialog
         Dialog {
             id: dialogue
             title: i18n.tr("Select Page")
             text: i18n.tr("Enter a page number and press enter")
             TextField {
			     id: pagefield
                 text: page
				 validator: IntValidator{bottom: 1; top: 1000;}
                 hasClearButton: false
				 onAccepted: {
				     page = pagefield.getText(0, 5)
				     saveSetting("page", page)
	    		     webview.url = qsTr("stadt_geht_loss.html#%1").arg(page)
				     PopupUtils.close(dialogue)
			     }
             }
		     Component.onCompleted: {
			     pagefield.cursorPosition = pagefield.text.length
			     pagefield.forceActiveFocus()
			 }
         }
    }

    Page {
	    flickable: null
        UbuntuWebView {
	        id: webview
            anchors.fill: parent
            }
        tools: ToolbarItems {
            back: Button {
	    	    anchors.centerIn: parent
                text: i18n.tr("Page: %1").arg(page)
                onClicked: PopupUtils.open(dialog)
            }
            ToolbarButton {
                action: Action {
                    text: i18n.tr("Back")
                    iconSource: Qt.resolvedUrl('image://theme/go-previous')
	    			onTriggered: {
	    			    page--
	    			    if (page <= 1) {
	    				    page = 1
	    				}
						saveSetting("page", page)
	    				webview.url = qsTr("stadt_geht_loss.html#%1").arg(page)
	    			    }
                }
            }
            ToolbarButton {
                action: Action {
                    text: i18n.tr("Forward")
                    iconSource: Qt.resolvedUrl('image://theme/go-next')
	    			onTriggered: {
	    			    page++
						saveSetting("page", page)
	    				webview.url = qsTr("stadt_geht_loss.html#%1").arg(page)
	    				}
                }
            }
          }
          Component.onCompleted: {
		      Theme.name = "Ubuntu.Components.Themes.Ambiance"
	    	  webview.url = qsTr("stadt_geht_loss.html#%1").arg(page)
          }
	}
}
